@@ -3,5 +3,6 @@
 ###
 
 read_surmisefunction <- function (filename) {
-  read.csv(filename)
+  sf <- read.csv(filename)
+  class(sf) <- unique(c("kmsurmisefunction", class(sf)))
 }
\ No newline at end of file
